/**
 * A point in a 2D cartesian coordinate system.
 */
export type Point = {
    x: number;
    y: number;
};
/**
 * @param p1
 * @param p2
 * @returns The Euclidean distance between two points `p1` and `p2`.
 */
export declare function dist(p1: Point, p2: Point): number;
/**
 * Get the bearing in radians from point `p1` to point `p2`.
 * @param p1 The origin point
 * @param p2 The destination point
 * @returns The bearing in radians from point `p1` to point `p2`
 */
export declare function bearing(p1: Point, p2: Point): number;
/**
 * Return the point that results from moving an initial point along a bearing
 * for a distance.
 * @param initialPoint The initial point
 * @param distance The distance along the bearing to move
 * @param bearingRadians The bearing in radians along which to move
 * @returns The point that is the result of moving `p` by `dist` units along `bearingRadians`.
 */
export declare function moveAlongBearing(initialPoint: Point, distance: number, bearingRadians: number): Point;
/**
 * Return the point that results from rotating an initial point
 * for a given amount around an axis point.
 * @param initialPoint The initial point
 * @param rotationRadians The amount to rotate around the axis
 * @param axisPoint The point to rotate around (defaults to the origin 0,0)
 * @returns
 */
export declare function rotateAroundPoint(initialPoint: Point, rotationRadians: number, axisPoint?: Point): Point;
