"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parsePattern = parsePattern;
exports.patternToString = patternToString;
const svg_path_1 = __importDefault(require("./svg-path"));
function parsePattern(s) {
    if (s === "solid") {
        return "solid";
    }
    const patternParts = s.split(";");
    return patternParts.map((part) => {
        const parameters = part.split(",");
        const path = svg_path_1.default.parse(parameters[0]);
        const offset = parsePixelOrPercent(parameters[1]);
        const interval = parsePixelOrPercent(parameters[2], {
            value: 100,
            type: "%",
        });
        const type = parameters[3] === "T" ? "T" : "F";
        return {
            path,
            offset,
            interval,
            type,
        };
    });
}
function parsePixelOrPercent(s, defaultValue) {
    if (!s || !s.length) {
        return defaultValue !== null && defaultValue !== void 0 ? defaultValue : { value: 0, type: "px" };
    }
    if (s.endsWith("%")) {
        const percent = Number(s.slice(0, s.length - 1));
        if (isNaN(percent)) {
            throw new Error(`Invalid pattern. Could not parse ${s} to number or percent.`);
        }
        return { value: percent, type: "%" };
    }
    const value = Number(s);
    if (isNaN(value)) {
        throw new Error(`Invalid pattern. Could not parse ${s} to number or percent.`);
    }
    return { value, type: "px" };
}
function patternToString(pattern) {
    if (pattern === "solid") {
        return "solid";
    }
    return pattern.map(partToString).join(";");
}
function partToString(part) {
    return `${svg_path_1.default.toString(part.path)},${pixelOrPercentToString(part.offset)},${pixelOrPercentToString(part.interval)},${part.type}`;
}
function pixelOrPercentToString(v) {
    if (v.type === "%") {
        return `${v.value}%`;
    }
    return v.value.toString();
}
